<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.0">
<context>
    <name>Badges</name>
    <message>
        <location filename="../qml/pages/Badges.qml" line="18"/>
        <source>BADGES</source>
        <translation>ROZETLER</translation>
    </message>
</context>
<context>
    <name>Checkin</name>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="18"/>
        <source>CHECK-IN DETAILS</source>
        <translation>CHECK-IN DETAYLARI</translation>
    </message>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="223"/>
        <source>TOTAL POINTS</source>
        <translation>TOPLAM PUAN</translation>
    </message>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="261"/>
        <source>EARNED BADGES</source>
        <translation>ROZETLERIN</translation>
    </message>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="283"/>
        <source>COMMENTS</source>
        <translation>YORUMLAR</translation>
    </message>
</context>
<context>
    <name>CheckinDialog</name>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="22"/>
        <source>NEW CHECK-IN</source>
        <translation>YENI CHECK-IN</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="48"/>
        <source>CHECK IN</source>
        <translation>CHECK IN</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="57"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="100"/>
        <source>Whats on your mind?</source>
        <translation>Aklından ne geçiyor?</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="129"/>
        <source>Sharing options</source>
        <translation>Paylaşım Seçenekleri</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="133"/>
        <source>Share with Friends</source>
        <translation>Arkadaşlarınla Paylaş</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="141"/>
        <source>Post to Facebook</source>
        <translation>Facebook&apos;da Paylaş</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="149"/>
        <source>Post to Twitter</source>
        <translation>Twitter&apos;da Paylaş</translation>
    </message>
</context>
<context>
    <name>CheckinHistory</name>
    <message>
        <location filename="../qml/pages/CheckinHistory.qml" line="24"/>
        <source>CHECK-IN HISTORY</source>
        <translation>CHECK-IN GEÇMİŞİ</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinHistory.qml" line="64"/>
        <source>Load More</source>
        <translation>Daha Fazla Yükle</translation>
    </message>
</context>
<context>
    <name>CommentDialog</name>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="26"/>
        <source>What is on your mind?</source>
        <translation>Aklından ne geçiyor?</translation>
    </message>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="38"/>
        <source>New awesome comment</source>
        <translation>Yeni harika yorum</translation>
    </message>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="69"/>
        <source>Comment!</source>
        <translation>Yorum Yap!</translation>
    </message>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="77"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
</context>
<context>
    <name>DebugSubmit</name>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="18"/>
        <source>DEBUG SUBMIT</source>
        <translation>DEBUG BİLDİR</translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="34"/>
        <source>Thank you for submit!&lt;br&gt;This will be implemented soon!</source>
        <translation>Bildirdiğiniz için teşekkürler!&lt;br&gt;Yakında eklenecek/düzeltilecektir!</translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="53"/>
        <source>SUBMIT</source>
        <translation>GÖNDER</translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="61"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="92"/>
        <source>You can help me with Nelisquare development by submitting debug info.

The following information are going to be submitted:</source>
        <translation>Bana debug bilginizi göndererek, Nelisquare&apos;i geliştirmemde yardımcı olabilirsiniz.⏎
⏎
Şu bilgiler gönderilecektir:
</translation>
    </message>
</context>
<context>
    <name>DebugWidget</name>
    <message>
        <location filename="../qml/components/DebugWidget.qml" line="14"/>
        <source>Unknown %1 event!</source>
        <translation>Bilinmeyen olay! : %1</translation>
    </message>
    <message>
        <location filename="../qml/components/DebugWidget.qml" line="47"/>
        <source>This event type is unknown.
You can help with resolution.</source>
        <translation>Bu olay türü bilinmiyor.
Çözüme yardımcı olabilirsiniz.</translation>
    </message>
</context>
<context>
    <name>FriendsFeed</name>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="43"/>
        <source>FRIENDS FEED</source>
        <translation>AKIŞ</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="221"/>
        <source>RECENT</source>
        <translation>HENÜZ</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="234"/>
        <source>NEARBY</source>
        <translation>YAKINDA</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="255"/>
        <source>Load More</source>
        <translation>Daha Fazla Yükle</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="402"/>
        <source>Sorry, Pages are not supported yet :(</source>
        <translation>Üzgünüm, Sayfalar henüz desteklenmiyor :(</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="472"/>
        <source>Sorry, no lists support yet :(</source>
        <translation>Üzgünüm, listeler henüz desteklenmiyor :(</translation>
    </message>
</context>
<context>
    <name>LeaderBoard</name>
    <message>
        <location filename="../qml/pages/LeaderBoard.qml" line="19"/>
        <source>YOU ARE #</source>
        <translation>SIRANIZ #</translation>
    </message>
    <message>
        <location filename="../qml/pages/LeaderBoard.qml" line="63"/>
        <source>&lt;b&gt;%1 points&lt;/b&gt; %2 checkins</source>
        <translation>&lt;b&gt;%1 puanla&lt;/b&gt; %2 check-in</translation>
    </message>
</context>
<context>
    <name>LikeBox</name>
    <message>
        <location filename="../qml/components/LikeBox.qml" line="33"/>
        <source>USER LIKES</source>
        <translation>KULLANICI BEĞENİLERİ</translation>
    </message>
</context>
<context>
    <name>ListViewEx</name>
    <message>
        <location filename="../qml/components/ListViewEx.qml" line="9"/>
        <source>Pull and hold to refresh...</source>
        <translation>Yenilemek için çekin ve bekleyin...</translation>
    </message>
    <message>
        <location filename="../qml/components/ListViewEx.qml" line="10"/>
        <source>Release to refresh...</source>
        <translation>Şimdi bırakın...</translation>
    </message>
</context>
<context>
    <name>Login24sq</name>
    <message>
        <location filename="../qml/pages/Login24sq.qml" line="42"/>
        <source>Sign In to Foursquare</source>
        <translation>Foursquare&apos;e giriş yap</translation>
    </message>
</context>
<context>
    <name>Mayorships</name>
    <message>
        <location filename="../qml/pages/Mayorships.qml" line="19"/>
        <source>MAYORSHIPS</source>
        <translation>MAYORLUKLAR</translation>
    </message>
</context>
<context>
    <name>NotificationDialog</name>
    <message>
        <location filename="../qml/components/NotificationDialog.qml" line="36"/>
        <source>OK</source>
        <translation>TAMAM</translation>
    </message>
</context>
<context>
    <name>Notifications</name>
    <message>
        <location filename="../qml/pages/Notifications.qml" line="24"/>
        <source>NOTIFICATIONS</source>
        <translation>BİLDİRİMLER</translation>
    </message>
    <message>
        <location filename="../qml/pages/Notifications.qml" line="51"/>
        <source>Mark all as read</source>
        <translation>Hepsini okundu olarak işaretle</translation>
    </message>
    <message>
        <location filename="../qml/pages/Notifications.qml" line="58"/>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
</context>
<context>
    <name>PageWrapper</name>
    <message>
        <location filename="../qml/components/PageWrapper.qml" line="88"/>
        <source>Check updates</source>
        <translation>Güncelle</translation>
    </message>
    <message>
        <location filename="../qml/components/PageWrapper.qml" line="94"/>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <location filename="../qml/components/PageWrapper.qml" line="100"/>
        <source>Exit</source>
        <translation>Çıkış</translation>
    </message>
</context>
<context>
    <name>Photo</name>
    <message>
        <location filename="../qml/pages/Photo.qml" line="20"/>
        <source>PHOTO</source>
        <translation>FOTOĞRAF</translation>
    </message>
</context>
<context>
    <name>PhotoAdd</name>
    <message>
        <location filename="../qml/pages/PhotoAdd.qml" line="18"/>
        <source>Select photo for upload</source>
        <translation>Yükleme için fotoğraf seçin</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoAdd.qml" line="56"/>
        <source>Error uploading photo!</source>
        <translation>Fotoğraf yükleme hatası!</translation>
    </message>
</context>
<context>
    <name>PhotoShareDialog</name>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="20"/>
        <source>PHOTO UPLOAD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="36"/>
        <source>UPLOAD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="86"/>
        <source>Sharing options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="90"/>
        <source>Public</source>
        <translation>Herkes</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="97"/>
        <source>Post to Facebook</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="104"/>
        <source>Post to Twitter</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="48"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
</context>
<context>
    <name>PhotosBox</name>
    <message>
        <location filename="../qml/components/PhotosBox.qml" line="8"/>
        <source>PHOTOS</source>
        <translation>FOTOĞRAFLAR</translation>
    </message>
</context>
<context>
    <name>PhotosGallery</name>
    <message>
        <location filename="../qml/pages/PhotosGallery.qml" line="13"/>
        <source>VENUE PHOTOS</source>
        <translation>MEKAN FOTOĞRAFLARI</translation>
    </message>
</context>
<context>
    <name>SettingSlider</name>
    <message>
        <location filename="../qml/components/SettingSlider.qml" line="50"/>
        <source>Off</source>
        <translation>Kapalı</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../qml/pages/Settings.qml" line="13"/>
        <source>updating...</source>
        <translation>güncelleniyor...</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="21"/>
        <source>SETTINGS</source>
        <translation>AYARLAR</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="53"/>
        <source>2012-2013 Basil Semuonov</source>
        <translation>2012-2013 Basil Semuonov</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="54"/>
        <source>Idea by Tommi Laukkanen</source>
        <translation>Fikir Sahibi: Tommi Laukkanen</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="55"/>
        <source>Shout out to @knobtviker</source>
        <translation>@knobtviker&apos;e seslen</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="56"/>
        <source>Design by Kim Venetvirta</source>
        <translation>Tasarım: Kim Venetvirta</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="57"/>
        <source>If any problems, tweet @basil_s</source>
        <translation>Sorunları @basil_s &apos;ye twit atın</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="58"/>
        <source>Version</source>
        <translation>Versiyon</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="60"/>
        <source>Build</source>
        <translation>Build</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="62"/>
        <source>Powered by Foursquare</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="64"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="70"/>
        <location filename="../qml/pages/Settings.qml" line="115"/>
        <source>Reset settings</source>
        <translation>Ayarları sıfırla</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="71"/>
        <source>This action will erase all data including auth token, application settings and cache.</source>
        <translation>Bütün veriler (auth token, ayarlar ve önbellek) silinecek.</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="72"/>
        <source>Yes, clear the data</source>
        <translation>Evet, veriyi sil</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="73"/>
        <source>No, thanks</source>
        <translation>Hayır, teşekkürler</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="81"/>
        <source>Language</source>
        <translation>Dil</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="109"/>
        <source>Notifications</source>
        <translation>Bildirimler</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="161"/>
        <source>UPDATES CHECK</source>
        <translation>GÜNCELLEME DENETLE</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="186"/>
        <source>None</source>
        <translation>Hiç</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="192"/>
        <source>Stable</source>
        <translation>Kararlı</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="197"/>
        <source>Beta</source>
        <translation>Beta</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="203"/>
        <source>Alpha</source>
        <translation>Alpha</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="209"/>
        <source>INTERVALS</source>
        <translation>ARALIKLAR</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="213"/>
        <source>GPS Unlock timeout</source>
        <translation>GPS Bekleme süresi</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="214"/>
        <source>Instant</source>
        <translation>Anlık</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="214"/>
        <source>%1 secs(s)</source>
        <translation>%1 saniye</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="214"/>
        <location filename="../qml/pages/Settings.qml" line="223"/>
        <source>Disabled</source>
        <translation>Devre Dışı</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="222"/>
        <source>Feed autoupdate time</source>
        <translation>Akıl güncelleme süresi</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="223"/>
        <source>Off</source>
        <translation>Kapalı</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="223"/>
        <source>%1 min(s)</source>
        <translation>%1 dakika</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="231"/>
        <source>PERMISSIONS</source>
        <translation>İZİNLER</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="234"/>
        <source>Allow use of Location Data</source>
        <translation>Herzaman Konum Kullan</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="242"/>
        <source>Always run in background</source>
        <translation>Herzaman arkada çalış</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="250"/>
        <source>Enable notifications</source>
        <translation>Bildirimleri Aç</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="258"/>
        <source>Feed at Home screen</source>
        <translation>Ev ekranında akış</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="266"/>
        <source>Push notifications</source>
        <translation>Otomatik bildirimler</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="317"/>
        <source>COLOR THEME</source>
        <translation>RENK TEMASI</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="336"/>
        <source>Light</source>
        <translation>Açık</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="342"/>
        <source>Dark</source>
        <translation>Koyu</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="348"/>
        <source>SCREEN ORIENTATION</source>
        <translation>EKRAN YÖNÜ</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="370"/>
        <source>Auto</source>
        <translation>Otomatik</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="376"/>
        <source>Landscape</source>
        <translation>Manzara</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="381"/>
        <source>Portrait</source>
        <translation>Portre</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="387"/>
        <source>STARTUP PAGE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="409"/>
        <source>Feed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="415"/>
        <source>Venues</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="420"/>
        <source>Self</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="426"/>
        <source>LANGUAGE</source>
        <translation>DİL</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="437"/>
        <source>MAP PROVIDER</source>
        <translation>HARITA SAĞLAYICI</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="460"/>
        <source>Nokia</source>
        <translation>Nokia</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="466"/>
        <source>Google</source>
        <translation>Google</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="471"/>
        <source>OSM</source>
        <translation>OSM</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="489"/>
        <source>IMAGE LOADING</source>
        <translation>RESİM YÜKLENİYOR</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="508"/>
        <source>All</source>
        <translation>Hepsi</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="513"/>
        <source>Cached</source>
        <translation>Bellekte</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="519"/>
        <source>INTEGRATION WITH APPS</source>
        <translation>UYGULAMA BAĞLANTILARI</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="525"/>
        <source>Download MOLO.ME</source>
        <translation>MOLO.ME &apos;yi indir</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="544"/>
        <source>MOLO.ME Photos</source>
        <translation>MOLO.ME Fotoğrafları</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="564"/>
        <source>APPLICATION CACHE</source>
        <translation>UYGULAMA BELLEĞİ</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="572"/>
        <source>Clear</source>
        <translation>Temizle</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="584"/>
        <source>Size: %1</source>
        <translation>Boyut: %1</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="590"/>
        <source>UI</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="593"/>
        <source>Reload UI</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="599"/>
        <source>AUTHENTICATION</source>
        <translation>KİMLİK KAYDI</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="602"/>
        <source>Reset authentication</source>
        <translation>Kimlik kaydını sıfırla</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="623"/>
        <source>ACCESS RATE LIMIT</source>
        <translation>ERİŞİM ORA LİMİTİ</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="629"/>
        <source>API requests available: %1 / %2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="635"/>
        <source>You are low on X-RATE requests</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="640"/>
        <source>DEBUG</source>
        <translation>DEBUG</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="643"/>
        <source>Enable debug</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="657"/>
        <source>Options will be available soon</source>
        <translation>Seçenekler yakında eklenecek</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="672"/>
        <source>General</source>
        <translation>Genel</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="673"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="674"/>
        <source>Service</source>
        <translation>Servis</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="675"/>
        <source>Debug</source>
        <translation>Debug</translation>
    </message>
</context>
<context>
    <name>SpecialsList</name>
    <message>
        <location filename="../qml/components/SpecialsList.qml" line="13"/>
        <source>VENUE SPECIALS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/components/SpecialsList.qml" line="31"/>
        <source>Unlocked!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TipDialog</name>
    <message>
        <location filename="../qml/components/TipDialog.qml" line="40"/>
        <source>Write some cool tip here</source>
        <translation>Tavsiye bırakın</translation>
    </message>
    <message>
        <location filename="../qml/components/TipDialog.qml" line="71"/>
        <source>ADD</source>
        <translation>EKLE</translation>
    </message>
    <message>
        <location filename="../qml/components/TipDialog.qml" line="79"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
</context>
<context>
    <name>TipPage</name>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="22"/>
        <source>Usefull tip</source>
        <translation>Tavsiye</translation>
    </message>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="149"/>
        <source>TIP PHOTO</source>
        <translation>TAVSIYE FOTOĞRAFI</translation>
    </message>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="171"/>
        <source>Save tip</source>
        <translation>Tavsiyeyi kaydet</translation>
    </message>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="179"/>
        <source>Mark as done</source>
        <translation>Yapıldı olarak işaretle</translation>
    </message>
</context>
<context>
    <name>TipsList</name>
    <message>
        <location filename="../qml/pages/TipsList.qml" line="18"/>
        <source>TIPS LIST</source>
        <translation>TAVSİYELER</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="12"/>
        <source>New update available</source>
        <translation>Güncelleştirme var</translation>
    </message>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="13"/>
        <source>Version: %1&lt;br&gt;Type: %2&lt;br&gt;Build: %3&lt;br&gt;&lt;br&gt;Changelog: &lt;br&gt;%4</source>
        <translation>Versiyon: %1&lt;br&gt;Tip: %2&lt;br&gt;Build: %3&lt;br&gt;&lt;br&gt;Changelog: &lt;br&gt;%4</translation>
    </message>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="19"/>
        <source>Update!</source>
        <translation>Güncelle!</translation>
    </message>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="20"/>
        <source>No, thanks</source>
        <translation>Hayır, teşekkürler</translation>
    </message>
</context>
<context>
    <name>User</name>
    <message>
        <location filename="../qml/pages/User.qml" line="59"/>
        <source>USER DETAILS</source>
        <translation>KULLAICI DETAYLARI</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="270"/>
        <source>Add Friend</source>
        <translation>Arkadaş Ekle</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="282"/>
        <source>Approve Friend</source>
        <translation>Akradaşı Onayla</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="289"/>
        <source>Deny friend</source>
        <translation>Reddet</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="301"/>
        <source>Remove Friend</source>
        <translation>Akradaşı Sil</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="314"/>
        <source>&lt;b&gt;SCORES&lt;/b&gt; (LAST 7 DAYS)</source>
        <translation>&lt;b&gt;SKORUN&lt;/b&gt; (SON 7 GÜN)</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="319"/>
        <source>BEST SCORE</source>
        <translation>EN YÜKSEK SKOR</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="377"/>
        <source>Badges</source>
        <translation>Rozetler</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="412"/>
        <source>Checkins</source>
        <translation>Check-in&apos;ler</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="447"/>
        <source>Mayorships</source>
        <translation>Başkanlıkar</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="482"/>
        <source>Friends</source>
        <translation>Arkadaşlar</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="517"/>
        <source>Photos</source>
        <translation>Fotoğraflar</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="553"/>
        <source>Tips</source>
        <translation>Tavsiyeler</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="569"/>
        <source>YOU ARE #</source>
        <translation>SIRANIZ #</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="594"/>
        <source>&lt;b&gt;%1 points&lt;/b&gt; %2 checkins</source>
        <translation>&lt;b&gt;%1 puanla&lt;/b&gt; %2 check-in</translation>
    </message>
</context>
<context>
    <name>UsersList</name>
    <message>
        <location filename="../qml/pages/UsersList.qml" line="21"/>
        <source>Loading...</source>
        <translation>Yükleniyor...</translation>
    </message>
    <message>
        <location filename="../qml/pages/UsersList.qml" line="30"/>
        <source>USER FRIENDS</source>
        <translation>KULLANICI ARKADAŞLARI</translation>
    </message>
    <message>
        <location filename="../qml/pages/UsersList.qml" line="33"/>
        <source>LIKERS LIST</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Venue</name>
    <message>
        <location filename="../qml/pages/Venue.qml" line="143"/>
        <source>VENUE PHOTOS</source>
        <translation>MEKAN FOTOĞRAFLARI</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="251"/>
        <source>CHECK-IN HERE!</source>
        <translation>CHECK-IN YAP!</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="273"/>
        <source>Venue doesn&apos;t have mayor yet!</source>
        <translation>Bu mekanın henüz Mayor&apos;u yok!</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="274"/>
        <source>is the mayor.</source>
        <translation>Mayor.</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="274"/>
        <source>It could be you!</source>
        <translation>Sen olabilirsin!</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="275"/>
        <source>%1 checkins</source>
        <translation>%1 Check-in&apos;ler</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="317"/>
        <source>BEST TIPS</source>
        <translation>EN İYİ TAVSİYELER</translation>
    </message>
</context>
<context>
    <name>VenueAdd</name>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="91"/>
        <source>Venue name</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>VenueMap</name>
    <message>
        <location filename="../qml/pages/VenueMap.qml" line="186"/>
        <source>GET ROUTE</source>
        <translation>YOL TARİFİ AL</translation>
    </message>
</context>
<context>
    <name>VenuesList</name>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="21"/>
        <source>NEARBY VENUES</source>
        <translation>YAKIN MEKANLAR</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="67"/>
        <source>GPS signal is fuzzy, cannot get your location</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="96"/>
        <source>Tap to search place...</source>
        <translation>Arama yapmak için dokun...</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="107"/>
        <source>SEARCH</source>
        <translation>ARA</translation>
    </message>
</context>
<context>
    <name>Welcome</name>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="29"/>
        <source>Welcome!</source>
        <translation>Hoşgeldin!</translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="46"/>
        <source>Please, login with Foursquare!</source>
        <translation>Lütfen Foursquare&apos;e giriş yapın!</translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="53"/>
        <source>Login</source>
        <translation>Giriş Yap</translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="67"/>
        <source>Foursquare privacy policy</source>
        <translation>Foursquare Gizlilik Politikası</translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="81"/>
        <source>Nelisquare privacy policy</source>
        <translation>Nelisquare Gizlilik Politikası</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../qml/main.qml" line="108"/>
        <source>Location data</source>
        <translation>Konum bilgisi</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="109"/>
        <source>Nelisquare requires use of user location data. Data is needed to make geo-location services work properly.</source>
        <translation>Nelisquare&apos;in konum bilgisine ihtiyacı var ve konum servisleri internet üzerinden çalışıyor.</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="110"/>
        <source>Allow</source>
        <translation>Kabul et</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="111"/>
        <source>Deny</source>
        <translation>Reddet</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="123"/>
        <source>Push notifications</source>
        <translation>Otomatik bildirimler</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="124"/>
        <source>Incoming push notifications are not supported at this version and are disabled by default.&lt;br/&gt;&lt;br/&gt;You will be promted again when they will be available at future versions.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/main.qml" line="128"/>
        <source>OK</source>
        <translation>TAMAM</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="161"/>
        <source>Check updates</source>
        <translation>Güncelle</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="167"/>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="173"/>
        <source>Exit</source>
        <translation>Çıkış</translation>
    </message>
</context>
</TS>